@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -62,7 +62,10 @@ class CloudSchedulerClientMeta(type):
     _transport_registry["grpc"] = CloudSchedulerGrpcTransport
     _transport_registry["grpc_asyncio"] = CloudSchedulerGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[CloudSchedulerTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[CloudSchedulerTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -169,10 +172,16 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         return self._transport
 
     @staticmethod
-    def job_path(project: str, location: str, job: str,) -> str:
+    def job_path(
+        project: str,
+        location: str,
+        job: str,
+    ) -> str:
         """Returns a fully-qualified job string."""
         return "projects/{project}/locations/{location}/jobs/{job}".format(
-            project=project, location=location, job=job,
+            project=project,
+            location=location,
+            job=job,
         )
 
     @staticmethod
@@ -185,9 +194,15 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def topic_path(project: str, topic: str,) -> str:
+    def topic_path(
+        project: str,
+        topic: str,
+    ) -> str:
         """Returns a fully-qualified topic string."""
-        return "projects/{project}/topics/{topic}".format(project=project, topic=topic,)
+        return "projects/{project}/topics/{topic}".format(
+            project=project,
+            topic=topic,
+        )
 
     @staticmethod
     def parse_topic_path(path: str) -> Dict[str, str]:
@@ -196,7 +211,9 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -209,9 +226,13 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -220,9 +241,13 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -231,9 +256,13 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -242,10 +271,14 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -430,6 +463,26 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
     ) -> pagers.ListJobsPager:
         r"""Lists jobs.
 
+        .. code-block:: python
+
+            from google.cloud import scheduler_v1
+
+            def sample_list_jobs():
+                # Create a client
+                client = scheduler_v1.CloudSchedulerClient()
+
+                # Initialize request argument(s)
+                request = scheduler_v1.ListJobsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_jobs(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.scheduler_v1.types.ListJobsRequest, dict]):
                 The request object. Request message for listing jobs
@@ -458,7 +511,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -489,12 +542,20 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListJobsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -511,6 +572,25 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
     ) -> job.Job:
         r"""Gets a job.
 
+        .. code-block:: python
+
+            from google.cloud import scheduler_v1
+
+            def sample_get_job():
+                # Create a client
+                client = scheduler_v1.CloudSchedulerClient()
+
+                # Initialize request argument(s)
+                request = scheduler_v1.GetJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.scheduler_v1.types.GetJobRequest, dict]):
                 The request object. Request message for
@@ -536,7 +616,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -567,7 +647,12 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -584,6 +669,25 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
     ) -> gcs_job.Job:
         r"""Creates a job.
 
+        .. code-block:: python
+
+            from google.cloud import scheduler_v1
+
+            def sample_create_job():
+                # Create a client
+                client = scheduler_v1.CloudSchedulerClient()
+
+                # Initialize request argument(s)
+                request = scheduler_v1.CreateJobRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.create_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.scheduler_v1.types.CreateJobRequest, dict]):
                 The request object. Request message for
@@ -622,7 +726,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, job])
         if request is not None and has_flattened_params:
@@ -655,7 +759,12 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -683,6 +792,24 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         retry the UpdateJob request until a successful response is
         received.
 
+        .. code-block:: python
+
+            from google.cloud import scheduler_v1
+
+            def sample_update_job():
+                # Create a client
+                client = scheduler_v1.CloudSchedulerClient()
+
+                # Initialize request argument(s)
+                request = scheduler_v1.UpdateJobRequest(
+                )
+
+                # Make the request
+                response = client.update_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.scheduler_v1.types.UpdateJobRequest, dict]):
                 The request object. Request message for
@@ -720,7 +847,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([job, update_mask])
         if request is not None and has_flattened_params:
@@ -753,7 +880,12 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -769,6 +901,22 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
     ) -> None:
         r"""Deletes a job.
 
+        .. code-block:: python
+
+            from google.cloud import scheduler_v1
+
+            def sample_delete_job():
+                # Create a client
+                client = scheduler_v1.CloudSchedulerClient()
+
+                # Initialize request argument(s)
+                request = scheduler_v1.DeleteJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_job(request=request)
+
         Args:
             request (Union[google.cloud.scheduler_v1.types.DeleteJobRequest, dict]):
                 The request object. Request message for deleting a job
@@ -788,7 +936,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -820,7 +968,10 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
 
         # Send the request.
         rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     def pause_job(
@@ -845,6 +996,25 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         [Job.State.ENABLED][google.cloud.scheduler.v1.Job.State.ENABLED]
         to be paused.
 
+        .. code-block:: python
+
+            from google.cloud import scheduler_v1
+
+            def sample_pause_job():
+                # Create a client
+                client = scheduler_v1.CloudSchedulerClient()
+
+                # Initialize request argument(s)
+                request = scheduler_v1.PauseJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.pause_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.scheduler_v1.types.PauseJobRequest, dict]):
                 The request object. Request message for
@@ -870,7 +1040,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -901,7 +1071,12 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -927,6 +1102,25 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         [Job.State.PAUSED][google.cloud.scheduler.v1.Job.State.PAUSED]
         to be resumed.
 
+        .. code-block:: python
+
+            from google.cloud import scheduler_v1
+
+            def sample_resume_job():
+                # Create a client
+                client = scheduler_v1.CloudSchedulerClient()
+
+                # Initialize request argument(s)
+                request = scheduler_v1.ResumeJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.resume_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.scheduler_v1.types.ResumeJobRequest, dict]):
                 The request object. Request message for
@@ -952,7 +1146,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -983,7 +1177,12 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1001,6 +1200,25 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         When this method is called, Cloud Scheduler will
         dispatch the job, even if the job is already running.
 
+        .. code-block:: python
+
+            from google.cloud import scheduler_v1
+
+            def sample_run_job():
+                # Create a client
+                client = scheduler_v1.CloudSchedulerClient()
+
+                # Initialize request argument(s)
+                request = scheduler_v1.RunJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.run_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.scheduler_v1.types.RunJobRequest, dict]):
                 The request object. Request message for forcing a job to
@@ -1027,7 +1245,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1058,7 +1276,12 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1079,7 +1302,9 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-scheduler",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-scheduler",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
