@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -224,6 +224,26 @@ class CloudSchedulerAsyncClient:
     ) -> pagers.ListJobsAsyncPager:
         r"""Lists jobs.
 
+        .. code-block:: python
+
+            from google.cloud import scheduler_v1beta1
+
+            def sample_list_jobs():
+                # Create a client
+                client = scheduler_v1beta1.CloudSchedulerClient()
+
+                # Initialize request argument(s)
+                request = scheduler_v1beta1.ListJobsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_jobs(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.scheduler_v1beta1.types.ListJobsRequest, dict]):
                 The request object. Request message for listing jobs
@@ -252,7 +272,7 @@ class CloudSchedulerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -293,12 +313,20 @@ class CloudSchedulerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListJobsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -315,6 +343,25 @@ class CloudSchedulerAsyncClient:
     ) -> job.Job:
         r"""Gets a job.
 
+        .. code-block:: python
+
+            from google.cloud import scheduler_v1beta1
+
+            def sample_get_job():
+                # Create a client
+                client = scheduler_v1beta1.CloudSchedulerClient()
+
+                # Initialize request argument(s)
+                request = scheduler_v1beta1.GetJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.scheduler_v1beta1.types.GetJobRequest, dict]):
                 The request object. Request message for
@@ -340,7 +387,7 @@ class CloudSchedulerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -381,7 +428,12 @@ class CloudSchedulerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -398,6 +450,25 @@ class CloudSchedulerAsyncClient:
     ) -> gcs_job.Job:
         r"""Creates a job.
 
+        .. code-block:: python
+
+            from google.cloud import scheduler_v1beta1
+
+            def sample_create_job():
+                # Create a client
+                client = scheduler_v1beta1.CloudSchedulerClient()
+
+                # Initialize request argument(s)
+                request = scheduler_v1beta1.CreateJobRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.create_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.scheduler_v1beta1.types.CreateJobRequest, dict]):
                 The request object. Request message for
@@ -437,7 +508,7 @@ class CloudSchedulerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, job])
         if request is not None and has_flattened_params:
@@ -470,7 +541,12 @@ class CloudSchedulerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -498,6 +574,24 @@ class CloudSchedulerAsyncClient:
         retry the UpdateJob request until a successful response is
         received.
 
+        .. code-block:: python
+
+            from google.cloud import scheduler_v1beta1
+
+            def sample_update_job():
+                # Create a client
+                client = scheduler_v1beta1.CloudSchedulerClient()
+
+                # Initialize request argument(s)
+                request = scheduler_v1beta1.UpdateJobRequest(
+                )
+
+                # Make the request
+                response = client.update_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.scheduler_v1beta1.types.UpdateJobRequest, dict]):
                 The request object. Request message for
@@ -535,7 +629,7 @@ class CloudSchedulerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([job, update_mask])
         if request is not None and has_flattened_params:
@@ -568,7 +662,12 @@ class CloudSchedulerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -584,6 +683,22 @@ class CloudSchedulerAsyncClient:
     ) -> None:
         r"""Deletes a job.
 
+        .. code-block:: python
+
+            from google.cloud import scheduler_v1beta1
+
+            def sample_delete_job():
+                # Create a client
+                client = scheduler_v1beta1.CloudSchedulerClient()
+
+                # Initialize request argument(s)
+                request = scheduler_v1beta1.DeleteJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_job(request=request)
+
         Args:
             request (Union[google.cloud.scheduler_v1beta1.types.DeleteJobRequest, dict]):
                 The request object. Request message for deleting a job
@@ -603,7 +718,7 @@ class CloudSchedulerAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -645,7 +760,10 @@ class CloudSchedulerAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def pause_job(
@@ -670,6 +788,25 @@ class CloudSchedulerAsyncClient:
         [Job.State.ENABLED][google.cloud.scheduler.v1beta1.Job.State.ENABLED]
         to be paused.
 
+        .. code-block:: python
+
+            from google.cloud import scheduler_v1beta1
+
+            def sample_pause_job():
+                # Create a client
+                client = scheduler_v1beta1.CloudSchedulerClient()
+
+                # Initialize request argument(s)
+                request = scheduler_v1beta1.PauseJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.pause_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.scheduler_v1beta1.types.PauseJobRequest, dict]):
                 The request object. Request message for
@@ -695,7 +832,7 @@ class CloudSchedulerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -736,7 +873,12 @@ class CloudSchedulerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -762,6 +904,25 @@ class CloudSchedulerAsyncClient:
         [Job.State.PAUSED][google.cloud.scheduler.v1beta1.Job.State.PAUSED]
         to be resumed.
 
+        .. code-block:: python
+
+            from google.cloud import scheduler_v1beta1
+
+            def sample_resume_job():
+                # Create a client
+                client = scheduler_v1beta1.CloudSchedulerClient()
+
+                # Initialize request argument(s)
+                request = scheduler_v1beta1.ResumeJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.resume_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.scheduler_v1beta1.types.ResumeJobRequest, dict]):
                 The request object. Request message for
@@ -787,7 +948,7 @@ class CloudSchedulerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -828,7 +989,12 @@ class CloudSchedulerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -846,6 +1012,25 @@ class CloudSchedulerAsyncClient:
         When this method is called, Cloud Scheduler will
         dispatch the job, even if the job is already running.
 
+        .. code-block:: python
+
+            from google.cloud import scheduler_v1beta1
+
+            def sample_run_job():
+                # Create a client
+                client = scheduler_v1beta1.CloudSchedulerClient()
+
+                # Initialize request argument(s)
+                request = scheduler_v1beta1.RunJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.run_job(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.scheduler_v1beta1.types.RunJobRequest, dict]):
                 The request object. Request message for forcing a job to
@@ -872,7 +1057,7 @@ class CloudSchedulerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -903,7 +1088,12 @@ class CloudSchedulerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -917,7 +1107,9 @@ class CloudSchedulerAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-scheduler",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-scheduler",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
