@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -32,7 +32,9 @@ from google.protobuf import empty_pb2  # type: ignore
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-scheduler",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-scheduler",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
@@ -81,6 +83,7 @@ class CloudSchedulerTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
+
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
@@ -152,10 +155,14 @@ class CloudSchedulerTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.create_job: gapic_v1.method.wrap_method(
-                self.create_job, default_timeout=600.0, client_info=client_info,
+                self.create_job,
+                default_timeout=600.0,
+                client_info=client_info,
             ),
             self.update_job: gapic_v1.method.wrap_method(
-                self.update_job, default_timeout=600.0, client_info=client_info,
+                self.update_job,
+                default_timeout=600.0,
+                client_info=client_info,
             ),
             self.delete_job: gapic_v1.method.wrap_method(
                 self.delete_job,
@@ -203,16 +210,18 @@ class CloudSchedulerTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.run_job: gapic_v1.method.wrap_method(
-                self.run_job, default_timeout=600.0, client_info=client_info,
+                self.run_job,
+                default_timeout=600.0,
+                client_info=client_info,
             ),
         }
 
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -278,5 +287,9 @@ class CloudSchedulerTransport(abc.ABC):
     ) -> Callable[[cloudscheduler.RunJobRequest], Union[job.Job, Awaitable[job.Job]]]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("CloudSchedulerTransport",)
