@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -65,9 +65,18 @@ class ListJobsRequest(proto.Message):
             while iterating through pages.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=5,)
-    page_token = proto.Field(proto.STRING, number=6,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=5,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=6,
+    )
 
 
 class ListJobsResponse(proto.Message):
@@ -94,8 +103,15 @@ class ListJobsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    jobs = proto.RepeatedField(proto.MESSAGE, number=1, message=gcs_job.Job,)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    jobs = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gcs_job.Job,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class GetJobRequest(proto.Message):
@@ -108,7 +124,10 @@ class GetJobRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateJobRequest(proto.Message):
@@ -130,8 +149,15 @@ class CreateJobRequest(proto.Message):
             in the response.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    job = proto.Field(proto.MESSAGE, number=2, message=gcs_job.Job,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    job = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=gcs_job.Job,
+    )
 
 
 class UpdateJobRequest(proto.Message):
@@ -151,9 +177,15 @@ class UpdateJobRequest(proto.Message):
             job are being updated.
     """
 
-    job = proto.Field(proto.MESSAGE, number=1, message=gcs_job.Job,)
+    job = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=gcs_job.Job,
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -167,7 +199,10 @@ class DeleteJobRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class PauseJobRequest(proto.Message):
@@ -180,7 +215,10 @@ class PauseJobRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ResumeJobRequest(proto.Message):
@@ -193,7 +231,10 @@ class ResumeJobRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class RunJobRequest(proto.Message):
@@ -206,7 +247,10 @@ class RunJobRequest(proto.Message):
             ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
