@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -71,7 +71,7 @@ class HttpTarget(proto.Message):
             characters after encoding.
         http_method (google.cloud.scheduler_v1beta1.types.HttpMethod):
             Which HTTP method to use for the request.
-        headers (Sequence[google.cloud.scheduler_v1beta1.types.HttpTarget.HeadersEntry]):
+        headers (Mapping[str, str]):
             The user can specify HTTP request headers to send with the
             job's HTTP request. This map contains the header field names
             and values. Repeated headers are not supported, but a header
@@ -121,15 +121,35 @@ class HttpTarget(proto.Message):
             This field is a member of `oneof`_ ``authorization_header``.
     """
 
-    uri = proto.Field(proto.STRING, number=1,)
-    http_method = proto.Field(proto.ENUM, number=2, enum="HttpMethod",)
-    headers = proto.MapField(proto.STRING, proto.STRING, number=3,)
-    body = proto.Field(proto.BYTES, number=4,)
+    uri = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    http_method = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum="HttpMethod",
+    )
+    headers = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=3,
+    )
+    body = proto.Field(
+        proto.BYTES,
+        number=4,
+    )
     oauth_token = proto.Field(
-        proto.MESSAGE, number=5, oneof="authorization_header", message="OAuthToken",
+        proto.MESSAGE,
+        number=5,
+        oneof="authorization_header",
+        message="OAuthToken",
     )
     oidc_token = proto.Field(
-        proto.MESSAGE, number=6, oneof="authorization_header", message="OidcToken",
+        proto.MESSAGE,
+        number=6,
+        oneof="authorization_header",
+        message="OidcToken",
     )
 
 
@@ -159,7 +179,7 @@ class AppEngineHttpTarget(proto.Message):
             arguments, and ``#`` fragments. If the relative URL is
             empty, then the root path "/" will be used. No spaces are
             allowed, and the maximum length allowed is 2083 characters.
-        headers (Sequence[google.cloud.scheduler_v1beta1.types.AppEngineHttpTarget.HeadersEntry]):
+        headers (Mapping[str, str]):
             HTTP request headers.
 
             This map contains the header field names and values. Headers
@@ -206,13 +226,29 @@ class AppEngineHttpTarget(proto.Message):
             [HttpMethod][google.cloud.scheduler.v1beta1.HttpMethod].
     """
 
-    http_method = proto.Field(proto.ENUM, number=1, enum="HttpMethod",)
+    http_method = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum="HttpMethod",
+    )
     app_engine_routing = proto.Field(
-        proto.MESSAGE, number=2, message="AppEngineRouting",
+        proto.MESSAGE,
+        number=2,
+        message="AppEngineRouting",
+    )
+    relative_uri = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    headers = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=4,
+    )
+    body = proto.Field(
+        proto.BYTES,
+        number=5,
     )
-    relative_uri = proto.Field(proto.STRING, number=3,)
-    headers = proto.MapField(proto.STRING, proto.STRING, number=4,)
-    body = proto.Field(proto.BYTES, number=5,)
 
 
 class PubsubTarget(proto.Message):
@@ -234,15 +270,25 @@ class PubsubTarget(proto.Message):
             The message payload for PubsubMessage.
             Pubsub message must contain either non-empty
             data, or at least one attribute.
-        attributes (Sequence[google.cloud.scheduler_v1beta1.types.PubsubTarget.AttributesEntry]):
+        attributes (Mapping[str, str]):
             Attributes for PubsubMessage.
             Pubsub message must contain either non-empty
             data, or at least one attribute.
     """
 
-    topic_name = proto.Field(proto.STRING, number=1,)
-    data = proto.Field(proto.BYTES, number=3,)
-    attributes = proto.MapField(proto.STRING, proto.STRING, number=4,)
+    topic_name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    data = proto.Field(
+        proto.BYTES,
+        number=3,
+    )
+    attributes = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=4,
+    )
 
 
 class AppEngineRouting(proto.Message):
@@ -360,10 +406,22 @@ class AppEngineRouting(proto.Message):
             of the default service when the job is attempted.
     """
 
-    service = proto.Field(proto.STRING, number=1,)
-    version = proto.Field(proto.STRING, number=2,)
-    instance = proto.Field(proto.STRING, number=3,)
-    host = proto.Field(proto.STRING, number=4,)
+    service = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    version = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    instance = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    host = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class OAuthToken(proto.Message):
@@ -387,8 +445,14 @@ class OAuthToken(proto.Message):
             will be used.
     """
 
-    service_account_email = proto.Field(proto.STRING, number=1,)
-    scope = proto.Field(proto.STRING, number=2,)
+    service_account_email = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    scope = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class OidcToken(proto.Message):
@@ -412,8 +476,14 @@ class OidcToken(proto.Message):
             target will be used.
     """
 
-    service_account_email = proto.Field(proto.STRING, number=1,)
-    audience = proto.Field(proto.STRING, number=2,)
+    service_account_email = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    audience = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
